@@ -1,14 +1,20 @@
 """
-Parsing errors
---------------
+Parsing errors.
+
 Here you find all the errors that may be thrown during the parsing process.
 """
 
-
 class ModuleDeclarationMissingException(Exception):
-    """ Error thrown when the module declaration is absent """
+    """Exception thrown when the module declaration is absent."""
+
     def __init__(self, filename):
-        """Initializes the Exception, with the filename so that the error message is more helpful."""
+        """Initialize the Exception, with the filename so that the error message is more helpful.
+
+        :param filename: Name of the file that is missing a module declaration.
+        :type filename: str
+        :returns: The exception explaining the error.
+        :rtype: Exception
+        """
         self.message = """\
 -- EMPTY MODULE --------------------------------------------- {0}
 
@@ -26,4 +32,11 @@ I am looking for one of the following things:
         super().__init__(self.message)
 
     def __call__(self, *args, **kwargs):
+        """
+        Raise the Exception.
+
+        :param args:
+        :param kwargs:
+        :return:
+        """
         raise self
