@@ -1,7 +1,10 @@
 import pytest
 import os
 import bagheera.main as main
+from bagheera.parser.parser import print_ast
 import itertools
+from difflib import SequenceMatcher
+
 
 fdescs_old = os.walk(os.path.join("test","examples"))
 next(fdescs_old)
@@ -14,6 +17,10 @@ fdescs,id_old = itertools.tee(fdescs_old)
 ids = map(fdesc2id,id_old)
 
 
+def similar(a, b):
+    return SequenceMatcher(None, a, b).ratio()
+
+
 @pytest.mark.parametrize('fdesc', fdescs, ids=ids)
 def test_examples(fdesc):
     path, dirs, files = fdesc
@@ -25,11 +32,13 @@ def test_examples(fdesc):
     for filename in files:
         if filename.endswith(".b"):
             parsed = main.parse(os.path.join(path,filename))
-            parsed_ast = parsed.dump()
+            parsed_ast = parsed.asDict()
         elif filename.endswith(".out"):
             with open(os.path.join(path,filename)) as f:
                 expected = f.read()
         elif filename.endswith(".ast"):
             with open(os.path.join(path,filename)) as f:
                 ast = f.read()
-    assert parsed_ast == ast
\ No newline at end of file
+    print_ast(parsed_ast)
+    assert similar(str(parsed_ast), ast) == 1
+
